@@ -51,7 +51,7 @@ public class App extends Window {
 		Handle hndl = getDock(getHandle());
 		if (null == hndl)
 			return null;
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Widget)obj;
 		return new Widget(hndl);
@@ -71,7 +71,7 @@ public class App extends Window {
 	 */
 	public MenuBar getMenuBar() {
 		Handle hndl = getMenubar(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (MenuBar)obj;
 		return new MenuBar(hndl);
@@ -83,7 +83,7 @@ public class App extends Window {
 	 */
 	public Widget getContents() {
 		Handle hndl = getContents(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Widget)obj;
 		return new Widget(hndl);
@@ -111,7 +111,7 @@ public class App extends Window {
 	 */
 	public StatusBar getStatusBar() {
 		Handle hndl = getStatusbar(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (StatusBar)obj;
 		return new StatusBar(hndl);
@@ -123,7 +123,7 @@ public class App extends Window {
 	 */
 	public VBox getVBox() {
 		Handle hndl = getVbox(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (VBox)obj;
 		return new VBox(hndl);
@@ -359,7 +359,7 @@ public class App extends Window {
 		Handle hndl = gnome_app_message(getHandle(), message);
 		if (null == hndl)
 			return null;
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Widget)obj;
 		return new Widget(hndl);
@@ -385,7 +385,7 @@ public class App extends Window {
 		Handle hndl = gnome_app_warning(getHandle(), warning);
 		if (null == hndl)
 			return null;
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Widget)obj;
 		return new Widget(hndl);
@@ -401,7 +401,7 @@ public class App extends Window {
 		Handle hndl = gnome_app_error(getHandle(), error);
 		if (null == hndl)
 			return null;
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Widget)obj;
 		return new Widget(hndl);
